%bcond_without tests

# We do not have Fedora infrastructure,
# so this aspect of Koschei is disabled
%bcond_with fedora_infra

%global upstreamrel 1

Name:           koschei
Version:        1.8.2
Release:        %mkrel 1
Summary:        Continuous integration for packages built with Koji
Group:          System/Servers
License:        GPLv2+
URL:            https://github.com/msimacek/%{name}
Source0:        https://github.com/msimacek/%{name}/archive/%{name}-%{version}-%{upstreamrel}.tar.gz

# Upstream patches

# Mageia specific patches
# We don't have js-jquery packaged, so revert to using online copy
Patch1000:      koschei-1.8.2-mga-Revert-Use-local-JQuery.patch

BuildArch:      noarch

BuildRequires:  python2-devel
BuildRequires:  python-setuptools
BuildRequires:  systemd
# for macro definition:
BuildRequires:  systemd-devel

%if %{with tests}
BuildRequires:       python-nose
BuildRequires:       python-mock
BuildRequires:       python-sqlalchemy
BuildRequires:       koji
BuildRequires:       python2-hawkey
BuildRequires:       python2-librepo
BuildRequires:       python-rpm
BuildRequires:       fedmsg
BuildRequires:       python-psycopg2
BuildRequires:       postgresql-server
BuildRequires:       python-flask
BuildRequires:       python-flask-sqlalchemy
BuildRequires:       python-flask-wtf
BuildRequires:       python-jinja2
BuildRequires:       python-dogpile-cache
%endif

%description
Service tracking dependency changes and rebuilding packages whose
dependencies change too much. It uses Koji scratch builds to do the rebuilds and
provides a web interface to the results.


%package common
Summary:        Actual python code for koschei backend and frontend
Group:          System/Servers
Requires:       python-sqlalchemy
Requires:       python-psycopg2
Requires:       python-rpm
Requires(pre):  shadow-utils
Obsoletes:      %{name} < 1.5.1

%description common
%{summary}.


%package admin
Summary:        Administration script and DB migrations for koschei
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python-alembic
Requires:       postgresql


%description admin
%{summary}.

%package frontend
Summary:        Web frontend for koschei using mod_wsgi
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       python-flask
Requires:       python-flask-sqlalchemy
Requires:       python-flask-wtf
Requires:       python-jinja2
Requires:       apache-mod_wsgi
Requires:       apache

%description frontend
%{summary}.

%package backend
Summary:        Koschei backend services
Group:          System/Servers
Requires:       %{name}-common = %{version}-%{release}
Requires:       koji
Requires:       python2-hawkey
Requires:       python2-librepo
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description backend
%{summary}.

%if %{with fedora_infra}
%package frontend-fedora
Summary:        Fedora-specific Koschei frontend plugins
Group:          System/Servers
Requires:       %{name}-frontend = %{version}-%{release}
Requires:       python-dogpile-cache

%description frontend-fedora
%{summary}.

%package backend-fedora
Summary:        Fedora-specific Koschei backend plugins
Group:          System/Servers
Requires:       %{name}-backend = %{version}-%{release}
Requires:       fedmsg
Requires:       python-dogpile-cache
Requires:       python-fedmsg-meta-fedora-infrastructure
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

%description backend-fedora
%{summary}.
%endif

%prep
%setup -q -n %{name}-%{name}-%{version}-%{upstreamrel}
%autopatch -p1

sed 's|@CACHEDIR@|%{_localstatedir}/cache/%{name}|g
     s|@DATADIR@|%{_datadir}/%{name}|g
     s|@VERSION@|%{version}|g
     s|@STATEDIR@|%{_sharedstatedir}/%{name}|g' config.cfg.template > config.cfg

%build
%py2_build

aux/gen-bash-completion.py >koschei-admin.bash

%install
%py2_install

mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/%{name}
mkdir -p %{buildroot}%{_sysconfdir}/httpd/conf.d

cp -p config-backend.cfg %{buildroot}%{_sysconfdir}/%{name}/config-backend.cfg
cp -p config-frontend.cfg %{buildroot}%{_sysconfdir}/%{name}/config-frontend.cfg
cp -p config-admin.cfg %{buildroot}%{_sysconfdir}/%{name}/config-admin.cfg
cp -p config.cfg %{buildroot}%{_datadir}/koschei/

install -dm 755 %{buildroot}%{_unitdir}
for unit in systemd/*; do
    install -pm 644 $unit %{buildroot}%{_unitdir}/
done

install -pm 755 admin.py %{buildroot}%{_bindir}/%{name}-admin

install -dm 755 %{buildroot}%{_localstatedir}/cache/%{name}/repodata
install -dm 755 %{buildroot}%{_sharedstatedir}/%{name}

cp -pr templates %{buildroot}%{_datadir}/%{name}/

cp -pr alembic/ alembic.ini %{buildroot}%{_datadir}/%{name}/
cp -pr static %{buildroot}%{_datadir}/%{name}/
cp -p %{name}.wsgi %{buildroot}%{_datadir}/%{name}/
cp -p httpd.conf %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf

install -dm 755 %{buildroot}%{_libexecdir}/%{name}
ln -s %{_bindir}/python %{buildroot}%{_libexecdir}/%{name}/koschei-scheduler
ln -s %{_bindir}/python %{buildroot}%{_libexecdir}/%{name}/koschei-watcher
ln -s %{_bindir}/python %{buildroot}%{_libexecdir}/%{name}/koschei-polling
ln -s %{_bindir}/python %{buildroot}%{_libexecdir}/%{name}/koschei-resolver

install -dm 755 %{buildroot}%{_sysconfdir}/bash_completion.d/
install -p -m 644 koschei-admin.bash %{buildroot}%{_sysconfdir}/bash_completion.d/

%if %{without fedora_infra}
rm -fv %{buildroot}%{python2_sitelib}/*/frontend/plugins/pkgdb.py*

rm -fv %{buildroot}%{_libexecdir}/%{name}/*watcher*
rm -fv %{buildroot}%{_unitdir}/*watcher*
rm -fv %{buildroot}%{python2_sitelib}/*/backend/plugins/fedmsg_publisher.py*
rm -fv %{buildroot}%{python2_sitelib}/*/backend/plugins/pkgdb.py*
rm -fv %{buildroot}%{python2_sitelib}/*/backend/services/watcher.py*
%endif


%if %{with tests}
%check
. aux/set-env.sh
pg_init
pg_start
trap pg_stop 0
%{__python2} setup.py test
%endif

%pre common
getent group %{name} >/dev/null || groupadd -r %{name}
# services and koschei-admin script is supposed to be run as this user
getent passwd %{name} >/dev/null || \
    useradd -r -g %{name} -d %{_localstatedir}/cache/%{name} -s /bin/sh \
    -c "Runs %{name} services" %{name}
exit 0

# Workaround for RHBZ#646523 - can't change symlink to directory
%pretrans frontend -p <lua>
dir = "%{_datadir}/%{name}/static"
dummy = posix.readlink(dir) and os.remove(dir)

%post backend
%systemd_post %{name}-scheduler.service
%systemd_post %{name}-polling.service
%systemd_post %{name}-resolver.service

%preun backend
%systemd_preun %{name}-scheduler.service
%systemd_preun %{name}-polling.service
%systemd_preun %{name}-resolver.service

%if %{with fedora_infra}
%post backend-fedora
%systemd_post %{name}-watcher.service

%preun backend-fedora
%systemd_preun %{name}-watcher.service

%endif

%files common
%license LICENSE.txt
%{python2_sitelib}/*
%exclude %{python2_sitelib}/*/frontend
%exclude %{python2_sitelib}/*/backend
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/config.cfg
%attr(755, %{name}, %{name}) %{_localstatedir}/cache/%{name}
%dir %{_sysconfdir}/%{name}
%attr(755, %{name}, %{name}) %dir %{_sharedstatedir}/%{name}

%files admin
%{_bindir}/%{name}-admin
%{_datadir}/%{name}/alembic/
%{_datadir}/%{name}/alembic.ini
%{_sysconfdir}/bash_completion.d
%config(noreplace) %{_sysconfdir}/%{name}/config-admin.cfg

%files frontend
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/config-frontend.cfg
%{_datadir}/%{name}/static
%{_datadir}/%{name}/templates
%{_datadir}/%{name}/%{name}.wsgi
%{python2_sitelib}/*/frontend
%exclude %{python2_sitelib}/*/frontend/plugins/pkgdb.py*

%files backend
%config(noreplace) %{_sysconfdir}/%{name}/config-backend.cfg
%{_libexecdir}/%{name}
%{_unitdir}/*
%exclude %{_libexecdir}/%{name}/*watcher*
%exclude %{_unitdir}/*watcher*
%{python2_sitelib}/*/backend
%exclude %{python2_sitelib}/*/backend/plugins/fedmsg_publisher.py*
%exclude %{python2_sitelib}/*/backend/plugins/pkgdb.py*
%exclude %{python2_sitelib}/*/backend/services/watcher.py*

%if %{with fedora_infra}
%files frontend-fedora
%{python2_sitelib}/*/frontend/plugins/pkgdb.py*

%files backend-fedora
%{_libexecdir}/%{name}/*watcher*
%{_unitdir}/*watcher*
%{python2_sitelib}/*/backend/plugins/fedmsg_publisher.py*
%{python2_sitelib}/*/backend/plugins/pkgdb.py*
%{python2_sitelib}/*/backend/services/watcher.py*
%endif



%changelog
* Mon Dec 12 2016 ngompa <ngompa> 1.8.2-1.mga6
+ Revision: 1074311
- Upgrade to 1.8.2

* Sun Oct 16 2016 tv <tv> 1.7-3.mga6
+ Revision: 1061151
- BR systemd-devel for macro definition (mga#12027)

* Sat May 28 2016 ngompa <ngompa> 1.7-2.mga6
+ Revision: 1019169
- imported package koschei

